@echo off
rem *******************************************************************************
rem  Licensed Materials - Property of IBM
rem  (c) Copyright IBM Corporation 2013. All Rights Reserved.
rem  
rem  Note to U.S. Government Users Restricted Rights:  
rem  Use, duplication or disclosure restricted by GSA ADP Schedule 
rem  Contract with IBM Corp. 
rem  *******************************************************************************

setlocal EnableDelayedExpansion
set /A RETURN_VALUE=0

set COPY_TRS_DATABASE_LOG=%SCRIPT_DIR:"=%\copy_trs_database.log
set COPY_TRS_DATABASE_LOG="%COPY_TRS_DATABASE_LOG%"
set OLD_TSP_FILE=%1
set OLD_HOME_DIR=%2
set OLD_CONTEXT_ROOT=%3
set NEW_TSP_FILE=%4
set NEW_HOME_DIR=%5
set NEW_CONTEXT_ROOT=%6

REM ***********************************************************************
REM Copy the TRS database directory. In 4.0, 4.0.1 and 4.0.2, the default
REM directory was server/conf/xx/tdb. In 4.0.3, the trs database directory
REM should be defined as a team server property. All cases must be taken 
REM into consideration. Also, the old TRS database may not exist if the 
REM LQE application did not connect to this application.
REM ***********************************************************************

set FIND_CMD=%SystemRoot%\system32\find.exe


REM  Determine if the TRS property was defined in the OLD TSP file
%FIND_CMD% "com.ibm.xtools.trs.database" %OLD_TSP_FILE% | %FIND_CMD% /V "#com.ibm.xtools.trs.database" > %COPY_TRS_DATABASE_LOG%
for /F "tokens=2 delims==" %%i in ('type %COPY_TRS_DATABASE_LOG%') do set OLD_TRS_DB_DIR=%%i
if "%OLD_TRS_DB_DIR%" == "" (
	set OLD_TRS_DB_DIR=tdb
)
	
REM Check whether the TRS database path is relative or not
rem debug:	echo OLD_TRS_DB_DIR=%OLD_TRS_DB_DIR%
set TMP_DIR=%OLD_TRS_DB_DIR:"=%
set TMP_DIR=%TMP_DIR:/=\%
for /f "tokens=1,2 delims=:" %%a in ("%TMP_DIR%") do (
    rem if a == to the %TMP_DIR arg, it means it did not contain a ':' and 
	rem we can safely assume a relative path
	if "%%a" == "%TMP_DIR%" (
  		rem Old text indices location is relative, store it as absolute
		cd /d %OLD_HOME_DIR%\%OLD_CONTEXT_ROOT%
		for /f "delims=" %%i in ('cd') do set OLD_TRS_DB_DIR="%%i\%TMP_DIR%"
	)else (
  		rem for a sanity check remove any \ encoding chars
  		rem remove any \ on the left hand side of colon delimiter
  		set left=%%a
  		set left=!left:\=!
  		set OLD_TRS_DB_DIR="!left!:%%b"
	)
)	
	
REM If the old TRS database directory does not exist, there is nothing to copy.
if NOT EXIST %OLD_TRS_DB_DIR% (
	set /A RETURN_VALUE = 0
	goto :LBLEND
)

	
REM Determine if the TRS property was defined in the NEW TSP file
%FIND_CMD% "com.ibm.xtools.trs.database" %NEW_TSP_FILE% | %FIND_CMD% /V "#com.ibm.xtools.trs.database" > %COPY_TRS_DATABASE_LOG%
for /F "tokens=2 delims==" %%i in ('type %COPY_TRS_DATABASE_LOG%') do set NEW_TRS_DB_DIR=%%i
if "%NEW_TRS_DB_DIR%" == "" (
	set NEW_TRS_DB_DIR=tdb
)
	
REM Check whether the TRS database path is relative or not
set TMP_DIR=%NEW_TRS_DB_DIR:"=%
set NEW_TRS_DB_DIR="%TMP_DIR:/=\%"
set TMP_DIR=%TMP_DIR:/=\%
for /f "tokens=1,2 delims=:" %%a in ("%TMP_DIR%") do (
    rem if a == to the %TMP_DIR arg, it means it did not contain a ':' and 
	rem we can safely assume a relative path
	if "%%a" == "%TMP_DIR%" (
  		rem New text indices location is relative, store it as absolute
		cd /d %NEW_HOME_DIR%\%NEW_CONTEXT_ROOT%
		for /f "delims=" %%i in ('cd') do set NEW_TRS_DB_DIR="%%i\%TMP_DIR%"
	)else (
  		rem for a sanity check remove any \ encoding chars
  		rem remove any \ on the left hand side of colon delimiter
  		set left=%%a
  		set left=!left:\=!
  		set NEW_TRS_DB_DIR="!left!:%%b"
	)
)	

	
REM IF the old and new TRS database directories are the same, nothing to copy.
if %OLD_TRS_DB_DIR% == %NEW_TRS_DB_DIR% (
	set /A RETURN_VALUE = 0
	goto :LBLEND
)
	
REM If the new TRS database directory exists, the user
REM must have performed a manual copy so do nothing
if EXIST %NEW_TRS_DB_DIR% (
	set /A RETURN_VALUE = 0
	goto :LBLEND
)
	
REM Copy the old TRS database hierarchy to the new directory
xcopy /s /c /i /q /k /o /y %OLD_TRS_DB_DIR% %NEW_TRS_DB_DIR% > nul
set RETURN_VALUE=%ERRORLEVEL%
	
REM If copy did not work, output an error message
if NOT %RETURN_VALUE% == 0 (
	call %MSG_FILE_PATH% COPY_TRS_DB_FAILED %OLD_TRS_DB_DIR% %NEW_TRS_DB_DIR%
)
	

:LBLEND
endlocal & exit /b %RETURN_VALUE%
